==> aws-cdk-lib-2.0.0-rc.20-sources.jar: software/amazon/awscdk/ISynthesisSession.java <==
package software.amazon.awscdk;

/**
 * (experimental) Represents a single session of synthesis.
 * <p>
 * Passed into <code>Construct.synthesize()</code> methods.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.31.0 (build 6fa403d)", date = "2021-09-01T10:25:51.444Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.$Module.class, fqn = "aws-cdk-lib.ISynthesisSession")
@software.amazon.jsii.Jsii.Proxy(ISynthesisSession.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
public interface ISynthesisSession extends software.amazon.jsii.JsiiSerializable {

    /**
     * (experimental) Cloud assembly builder.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @org.jetbrains.annotations.NotNull software.amazon.awscdk.cxapi.CloudAssemblyBuilder getAssembly();

    /**
     * (experimental) Cloud assembly builder.
     */
    void setAssembly(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.cxapi.CloudAssemblyBuilder value);

    /**
     * (experimental) The output directory for this synthesis session.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @org.jetbrains.annotations.NotNull java.lang.String getOutdir();

    /**
     * (experimental) The output directory for this synthesis session.
     */
    void setOutdir(final @org.jetbrains.annotations.NotNull java.lang.String value);

    /**
     * (experimental) Whether the stack should be validated after synthesis to check for error metadata.
     * <p>
     * Default: - false
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.lang.Boolean getValidateOnSynth() {
        return null;
    }

    /**
     * (experimental) Whether the stack should be validated after synthesis to check for error metadata.
     * <p>
     * Default: - false
     */
    @software.amazon.jsii.Optional
    default void setValidateOnSynth(final @org.jetbrains.annotations.Nullable java.lang.Boolean value) {
        throw new UnsupportedOperationException("'void " + getClass().getCanonicalName() + "#setValidateOnSynth(@org.jetbrains.annotations.Nullable java.lang.Boolean)' is not implemented!");
    }

    /**
     * A proxy class which represents a concrete javascript instance of this type.
     */
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.ISynthesisSession.Jsii$Default {
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
        }

        /**
         * (experimental) Cloud assembly builder.
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public final @org.jetbrains.annotations.NotNull software.amazon.awscdk.cxapi.CloudAssemblyBuilder getAssembly() {
            return software.amazon.jsii.Kernel.get(this, "assembly", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.cxapi.CloudAssemblyBuilder.class));
        }

        /**
         * (experimental) Cloud assembly builder.
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public final void setAssembly(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.cxapi.CloudAssemblyBuilder value) {
            software.amazon.jsii.Kernel.set(this, "assembly", java.util.Objects.requireNonNull(value, "assembly is required"));
        }

        /**
         * (experimental) The output directory for this synthesis session.
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public final @org.jetbrains.annotations.NotNull java.lang.String getOutdir() {
            return software.amazon.jsii.Kernel.get(this, "outdir", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         * (experimental) The output directory for this synthesis session.
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public final void setOutdir(final @org.jetbrains.annotations.NotNull java.lang.String value) {
            software.amazon.jsii.Kernel.set(this, "outdir", java.util.Objects.requireNonNull(value, "outdir is required"));
        }

        /**
         * (experimental) Whether the stack should be validated after synthesis to check for error metadata.
         * <p>
         * Default: - false
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public final @org.jetbrains.annotations.Nullable java.lang.Boolean getValidateOnSynth() {
            return software.amazon.jsii.Kernel.get(this, "validateOnSynth", software.amazon.jsii.NativeType.forClass(java.lang.Boolean.class));
        }

        /**
         * (experimental) Whether the stack should be validated after synthesis to check for error metadata.
         * <p>
         * Default: - false
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public final void setValidateOnSynth(final @org.jetbrains.annotations.Nullable java.lang.Boolean value) {
            software.amazon.jsii.Kernel.set(this, "validateOnSynth", value);
        }
    }

    /**
     * Internal default implementation for {@link ISynthesisSession}.
     */
    @software.amazon.jsii.Internal
    interface Jsii$Default extends ISynthesisSession {

        /**
         * (experimental) Cloud assembly builder.
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        default @org.jetbrains.annotations.NotNull software.amazon.awscdk.cxapi.CloudAssemblyBuilder getAssembly() {
            return software.amazon.jsii.Kernel.get(this, "assembly", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.cxapi.CloudAssemblyBuilder.class));
        }

        /**
         * (experimental) Cloud assembly builder.
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        default void setAssembly(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.cxapi.CloudAssemblyBuilder value) {
            software.amazon.jsii.Kernel.set(this, "assembly", java.util.Objects.requireNonNull(value, "assembly is required"));
        }

        /**
         * (experimental) The output directory for this synthesis session.
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        default @org.jetbrains.annotations.NotNull java.lang.String getOutdir() {
            return software.amazon.jsii.Kernel.get(this, "outdir", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         * (experimental) The output directory for this synthesis session.
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        default void setOutdir(final @org.jetbrains.annotations.NotNull java.lang.String value) {
            software.amazon.jsii.Kernel.set(this, "outdir", java.util.Objects.requireNonNull(value, "outdir is required"));
        }

        /**
         * (experimental) Whether the stack should be validated after synthesis to check for error metadata.
         * <p>
         * Default: - false
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        default @org.jetbrains.annotations.Nullable java.lang.Boolean getValidateOnSynth() {
            return software.amazon.jsii.Kernel.get(this, "validateOnSynth", software.amazon.jsii.NativeType.forClass(java.lang.Boolean.class));
        }

        /**
         * (experimental) Whether the stack should be validated after synthesis to check for error metadata.
         * <p>
         * Default: - false
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        default void setValidateOnSynth(final @org.jetbrains.annotations.Nullable java.lang.Boolean value) {
            software.amazon.jsii.Kernel.set(this, "validateOnSynth", value);
        }
    }
}

==> aws-cdk-lib-2.10.0-sources.jar: software/amazon/awscdk/ISynthesisSession.java <==
package software.amazon.awscdk;

/**
 * Represents a single session of synthesis.
 * <p>
 * Passed into <code>Construct.synthesize()</code> methods.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.52.1 (build 5ccc8f6)", date = "2022-01-29T04:34:06.878Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.$Module.class, fqn = "aws-cdk-lib.ISynthesisSession")
@software.amazon.jsii.Jsii.Proxy(ISynthesisSession.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface ISynthesisSession extends software.amazon.jsii.JsiiSerializable {

    /**
     * Cloud assembly builder.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull software.amazon.awscdk.cxapi.CloudAssemblyBuilder getAssembly();

    /**
     * Cloud assembly builder.
     */
    void setAssembly(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.cxapi.CloudAssemblyBuilder value);

    /**
     * The output directory for this synthesis session.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getOutdir();

    /**
     * The output directory for this synthesis session.
     */
    void setOutdir(final @org.jetbrains.annotations.NotNull java.lang.String value);

    /**
     * Whether the stack should be validated after synthesis to check for error metadata.
     * <p>
     * Default: - false
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.Boolean getValidateOnSynth() {
        return null;
    }

    /**
     * Whether the stack should be validated after synthesis to check for error metadata.
     * <p>
     * Default: - false
     */
    @software.amazon.jsii.Optional
    default void setValidateOnSynth(final @org.jetbrains.annotations.Nullable java.lang.Boolean value) {
        throw new UnsupportedOperationException("'void " + getClass().getCanonicalName() + "#setValidateOnSynth(@org.jetbrains.annotations.Nullable java.lang.Boolean)' is not implemented!");
    }

    /**
     * A proxy class which represents a concrete javascript instance of this type.
     */
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.ISynthesisSession.Jsii$Default {
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
        }

        /**
         * Cloud assembly builder.
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public final @org.jetbrains.annotations.NotNull software.amazon.awscdk.cxapi.CloudAssemblyBuilder getAssembly() {
            return software.amazon.jsii.Kernel.get(this, "assembly", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.cxapi.CloudAssemblyBuilder.class));
        }

        /**
         * Cloud assembly builder.
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public final void setAssembly(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.cxapi.CloudAssemblyBuilder value) {
            software.amazon.jsii.Kernel.set(this, "assembly", java.util.Objects.requireNonNull(value, "assembly is required"));
        }

        /**
         * The output directory for this synthesis session.
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public final @org.jetbrains.annotations.NotNull java.lang.String getOutdir() {
            return software.amazon.jsii.Kernel.get(this, "outdir", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         * The output directory for this synthesis session.
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public final void setOutdir(final @org.jetbrains.annotations.NotNull java.lang.String value) {
            software.amazon.jsii.Kernel.set(this, "outdir", java.util.Objects.requireNonNull(value, "outdir is required"));
        }

        /**
         * Whether the stack should be validated after synthesis to check for error metadata.
         * <p>
         * Default: - false
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public final @org.jetbrains.annotations.Nullable java.lang.Boolean getValidateOnSynth() {
            return software.amazon.jsii.Kernel.get(this, "validateOnSynth", software.amazon.jsii.NativeType.forClass(java.lang.Boolean.class));
        }

        /**
         * Whether the stack should be validated after synthesis to check for error metadata.
         * <p>
         * Default: - false
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public final void setValidateOnSynth(final @org.jetbrains.annotations.Nullable java.lang.Boolean value) {
            software.amazon.jsii.Kernel.set(this, "validateOnSynth", value);
        }
    }

    /**
     * Internal default implementation for {@link ISynthesisSession}.
     */
    @software.amazon.jsii.Internal
    interface Jsii$Default extends ISynthesisSession {

        /**
         * Cloud assembly builder.
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        default @org.jetbrains.annotations.NotNull software.amazon.awscdk.cxapi.CloudAssemblyBuilder getAssembly() {
            return software.amazon.jsii.Kernel.get(this, "assembly", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.cxapi.CloudAssemblyBuilder.class));
        }

        /**
         * Cloud assembly builder.
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        default void setAssembly(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.cxapi.CloudAssemblyBuilder value) {
            software.amazon.jsii.Kernel.set(this, "assembly", java.util.Objects.requireNonNull(value, "assembly is required"));
        }

        /**
         * The output directory for this synthesis session.
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        default @org.jetbrains.annotations.NotNull java.lang.String getOutdir() {
            return software.amazon.jsii.Kernel.get(this, "outdir", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         * The output directory for this synthesis session.
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        default void setOutdir(final @org.jetbrains.annotations.NotNull java.lang.String value) {
            software.amazon.jsii.Kernel.set(this, "outdir", java.util.Objects.requireNonNull(value, "outdir is required"));
        }

        /**
         * Whether the stack should be validated after synthesis to check for error metadata.
         * <p>
         * Default: - false
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        default @org.jetbrains.annotations.Nullable java.lang.Boolean getValidateOnSynth() {
            return software.amazon.jsii.Kernel.get(this, "validateOnSynth", software.amazon.jsii.NativeType.forClass(java.lang.Boolean.class));
        }

        /**
         * Whether the stack should be validated after synthesis to check for error metadata.
         * <p>
         * Default: - false
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        default void setValidateOnSynth(final @org.jetbrains.annotations.Nullable java.lang.Boolean value) {
            software.amazon.jsii.Kernel.set(this, "validateOnSynth", value);
        }
    }
}
